### Name: topmodel
### Title: implementation of the hydrological model TOPMODEL
### Aliases: topmodel
### Keywords: models

### ** Examples

data(huagrahuma)
attach(huagrahuma)

## returns the simulated runoff (Qobs not given)
Qsim <- topmodel(parameters,topidx,delay,rain,ET0)

## returns a list of simulated runoff (Qobs), overland flow (qo), subsurface flow (qs) and storage (S):
topmodel(parameters,topidx,delay,rain,ET0,verbose = TRUE)

## plot observed and simulated discharge:
plot(Qobs)
points(Qsim, col="red", type="l")

## For a Monte carlo run with random sampling, we construct a parameter matrix:

runs<-10

qs0   <- runif(runs)*4e-5
lnTe  <- runif(runs)*3-2
m     <- runif(runs)*0.2
Sr0   <- runif(runs)*0.02
Srmax <- runif(runs)*2
td    <- runif(runs)*3-3
vch   <- 1000
vr    <- 100+runif(runs)*2400
k0    <- runif(runs)*0.01
CD    <- runif(runs)*5
dt    <- 0.25

parameters<-cbind(qs0,lnTe,m,Sr0,Srmax,td,vch,vr,k0,CD,dt)

## returns an array of 10 Nash Sutcliffe efficiencies; one for each parameter set:
result<-topmodel(parameters,topidx,delay,rain,ET0,Qobs = Qobs)




